@@ -7,7 +7,7 @@ package conf;  # Don't remove this line!
 #
 # Administrator's email address
 #
-$ADDRESS = 'root@localhost';
+$ADDRESS = 'webmaster@moerbeke';
 
 
 #===================================================================
@@ -31,19 +31,9 @@ $ALLOW_FILE =	".*\\.(?:$HTML_SUFFIX)|.*\\.txt" . # HTML, plain text
 		"|.*\\.pdf|.*\\.ps" . 		   # PDF, PostScript
 		"|.*\\.tex|.*\\.dvi" .   	   # TeX, DVI
 		"|.*\\.rpm|.*\\.deb" .   	   # RPM, DEB
-		"|.*\\.doc|.*\\.xls|.*\\.pp[st]" . # Word, Excel, PowerPoint
-		"|.*\\.docx|.*\\.xlsx|.*\\.pp[st]x" . # MS-OfficeOpenXML Word, Excel, PowerPoint
-		"|.*\\.vs[dst]|.*\\.v[dst]x" .     # Visio
+		"|.*\\.doc|.*\\.xls|.*\\.ppt" .	   # Word, Excel, PowerPoint
 		"|.*\\.j[sabf]w|.*\\.jtd" .        # Ichitaro 4, 5, 6, 7, 8
-		"|.*\\.sx[widc]" .                 # OpenOffice Writer,Calc,Impress,Draw
-		"|.*\\.od[tspg]" .                 # OpenOffice2.0
-		"|.*\\.rtf" .                      # Rich Text Format
-		"|.*\\.hdml|.*\\.mht" .            # HDML MHTML
-		"|.*\\.mp3" .                      # MP3
-		"|.*\\.gnumeric" .                 # Gnumeric
-		"|.*\\.kwd|.*\\.ksp" .             # KWord, KSpread
-		"|.*\\.kpr|.*\\.flw" .             # KPresenter, Kivio
-		"|.*\\.eml|\\d+|[-\\w]+\\.[1-9n]"; # Mail/News, man
+		"|\\d+|[-\\w]+\\.[1-9n]";          # Mail/News, man
 
 #
 # This pattern specifies file names which will NOT be targeted.
@@ -53,14 +43,6 @@ $ALLOW_FILE =	".*\\.(?:$HTML_SUFFIX)|.*\\.txt" . # HTML, plain text
 #
 $DENY_FILE = ".*\\.(gif|png|jpg|jpeg)|.*\\.tar\\.gz|core|.*\\.bak|.*~|\\..*|\x23.*";
 
-#
-# This pattern specifies DDN(DOS Device Name) which will NOT be targeted.
-# NOTE: Only for Windows.
-#       Do NOT use `$' or `^' anchors.
-#       Case-insensitive.
-#
-$DENY_DDN = "con|aux|nul|prn|lpt[1-9]|com[1-9][0-9]?|clock\$|xmsxxxx0";
-
 #
 # This pattern specifies PATHNAMEs which will NOT be targeted.
 # NOTE: Usually specified by --exclude=regex option.
@@ -68,7 +50,7 @@ $DENY_DDN = "con|aux|nul|prn|lpt[1-9]|com[1-9][0-9]?|clock\$|xmsxxxx0";
 $EXCLUDE_PATH = undef;
 
 #
-# This pattern specifies file names which can be omitted
+# This pattern specifies file names which can be omitted 
 # in URI.  e.g., 'index.html|index.htm|Default.html'
 #
 # NOTE: This is similar to Apache's "DirectoryIndex" directive.
@@ -76,19 +58,19 @@ $EXCLUDE_PATH = undef;
 $DIRECTORY_INDEX = "";
 
 #
-# This pattern specifies Mail/News's fields in its header which
+# This pattern specifies Mail/News's fields in its header which 
 # should be searchable.  NOTE: case-insensitive
 #
 $REMAIN_HEADER = "From|Date|Message-ID";
 
 #
-# This pattern specifies fields which used for field-specified
+# This pattern specifies fields which used for field-specified 
 # searching.  NOTE: case-insensitive
 # 
 $SEARCH_FIELD = "message-id|subject|from|date|uri|newsgroups|to|summary|size";
 
 #
-# This pattern specifies meta tags which used for field-specified
+# This pattern specifies meta tags which used for field-specified 
 # searching.  NOTE: case-insensitive
 #
 $META_TAGS = "keywords|description";
@@ -100,20 +82,13 @@ $META_TAGS = "keywords|description";
 %FIELD_ALIASES = ('title' => 'subject', 'author' => 'from');
 
 #
-# This pattern specifies HTML elements which should be replaced with
-# null string when removing them. Normally, the elements are replaced
+# This pattern specifies HTML elements which should be replaced with 
+# null string when removing them. Normally, the elements are replaced 
 # with a single space character.
 #
 $NON_SEPARATION_ELEMENTS = 'A|TT|CODE|SAMP|KBD|VAR|B|STRONG|I|EM|CITE|FONT|U|'.
                        'STRIKE|BIG|SMALL|DFN|ABBR|ACRONYM|Q|SUB|SUP|SPAN|BDO';
 
-#
-# This pattern specifies attribute of a HTML tag which should be
-# searchable.
-#
-$HTML_ATTRIBUTES = 'ALT|SUMMARY|TITLE';
-
-
 #===================================================================
 # 
 # Critical Numbers
@@ -127,15 +102,15 @@ $HTML_ATTRIBUTES = 'ALT|SUMMARY|TITLE';
 $ON_MEMORY_MAX   = 5000000;
 
 #
-# The max file size for indexing. Files larger than this
+# The max file size for indexing. Files larger than this 
 # will be ignored.
-# NOTE: This value is usually larger than TEXT_SIZE_MAX because
+# NOTE: This value is usually larger than TEXT_SIZE_MAX because 
 #       binary-formated files such as PDF, Word are larger.
 #
 $FILE_SIZE_MAX   = 2000000;
 
 #
-# The max text size for indexing. Files larger than this
+# The max text size for indexing. Files larger than this 
 # will be ignored.
 #
 $TEXT_SIZE_MAX   =  600000;
@@ -149,7 +124,7 @@ $WORD_LENG_MAX   = 128;
 #
 # Weights for HTML elements which are used for term weightning.
 #
-%Weight =
+%Weight = 
     (
      'html' => {
          'title'  => 16,
@@ -177,11 +152,11 @@ $WORD_LENG_MAX   = 128;
 
 #
 # The max length of a HTML-tagged string which can be processed for
-# term weighting.
-# NOTE: There are not a few people has a bad manner using
+# term weighting. 
+# NOTE: There are not a few people has a bad manner using 
 #       <h[1-6]> for changing a font size.
 #
-$INVALID_LENG = 128;
+$INVALID_LENG = 128; 
 
 #
 # The max length of a field.
@@ -196,36 +171,30 @@ $MAX_FIELD_LENGTH = 200;
 #
 
 #
-# Network Kanji Filter nkf v1.71 or later
+# Network Kanji Filter nkf v1.62 or later
 #
-$NKF = "module_nkf";
+$NKF = "module_nkf"; 
 
 #
-# KAKASI 2.x or later
-# Text::Kakasi 1.05 or later
+# KAKASI
 #
-$KAKASI = "/usr/local/bin/kakasi -ieuc -oeuc -w";
+$KAKASI = "module_kakasi";
 
 #
-# ChaSen 2.02 or later (simple wakatigaki)
-# Text::ChaSen 1.03
+# ChaSen 1.51 or later (simple wakatigaki)
 #
-$CHASEN = "no";
+$CHASEN = "module_chasen";
 
 #
-# ChaSen 2.02 or later (with noun words extraction)
+# ChaSen 1.51 or later (with noun words extraction)
 #
-$CHASEN_NOUN = "no";
+$CHASEN_NOUN = "module_chasen -j -F '\%m %H\\n'";
 
 #
-# MeCab
-#
-$MECAB = "no";
-
-#
-# Default Japanese processer: KAKASI or ChaSen or MeCab.
+# Default Japanese processer: KAKASI or ChaSen.
 #
 $WAKATI  = $KAKASI;
+$WAKATI  = $CHASEN;
 
 
 #===================================================================
@@ -235,10 +204,6 @@ $WAKATI  = $KAKASI;
 # $LIBDIR = "@PERLLIBDIR@";
 # $FILTERDIR = "@FILTERDIR@";
 # $TEMPLATEDIR = "@TEMPLATEDIR@";
-#
-#[WIN] $LIBDIR = 'C:/namazu/share/namazu/pl';
-#[WIN] $FILTERDIR = 'C:/namazu/share/namazu/filter';
-#[WIN] $TEMPLATEDIR = 'C:/namazu/share/namazu/template';
 
 1;
 
